import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)

/**
 * The spike of the game. It moves and bounces off the walls and the paddle.
 * 
 * @author mik
 * @version 1.0
 */
public class Spike extends Actor
{
    private int x;        // x movement speed
    private int y;         // y movement speed
    private int count = 2;
    
    private boolean stuck = true;   // stuck to paddle
    
    /**
     * Act. Move if we're not stuck.
     */
    public void act() //when spike is not stuck, it will move
    {
        if (!stuck) 
        {
            move();
            checkOut();
        }
    }
  
    public void move()//check what we've hit.
    {
        setLocation (getX() + x, getY() + y);
        checkPaddle();
        checkWalls();
        checkBubble();
        ((BubbleWorld) getWorld()).winGame();
    }
      
    private void checkWalls()//Check whether we've hit one of the three walls. Reverse direction if necessary.
    {
        if (getX() == 0 || getX() == getWorld().getWidth()-1) {
            x = - x;
        }
        if (getY() == 0) {
            y = -y;
        }
    }
    
   //Keep the ball alive by using the paddle and preventing the ball from dropping 
    private void checkOut()
    {//this is set for detecting when the spike misses the paddle. 
        //in this case, when the spikes miss the paddle, your life will be reduced and object will be removed 
        if (getY() == getWorld().getHeight()-1) 
        {
            ((BubbleWorld) getWorld()).reduceLives();
            ((BubbleWorld) getWorld()).spikeIsOut();
            getWorld().removeObject(this);
            
        }
    }
    private void checkBubble()
    {
        Actor bubble = getOneIntersectingObject(Bubble.class);
        if (bubble != null) 
        {
            y = -y;
            int offset = getX() - bubble.getX();
            x = x + (offset/10);
            if (x > 7) 
            {
                x = 7;
            }
            if (x < -7) 
            {
                x = -7;
            }
          chancePowerUp();
          getWorld().removeObject(bubble);
        }            
    }
      private void checkPaddle()
    {
        Actor paddle = getOneIntersectingObject(Paddle.class);
        if (paddle != null) 
        {
            y = -y;
            int offset = getX() - paddle.getX();
            x = x + (offset/10);
            if (x > 7) 
            {
                x = 7;
            }
            if (x < -7) 
            {
                x = -7;
            }
        }            
    } 
    
    public void move(int dist)// Move the spike a given distance sideways.
    {
        setLocation (getX() + dist, getY());
    }
  
    public void release()//Release the spike from the paddle.
    {
        x = Greenfoot.getRandomNumber(11) - 5;
        y = -5;
        stuck = false;
    }
        public void chancePowerUp()
    {
       if(Greenfoot.getRandomNumber(60) == 1)
       {
           getWorld().addObject(new NewLife(), (this.getX()), (this.getY()));
       }
       if(Greenfoot.getRandomNumber(50) == 1)
       {
           getWorld().addObject(new MultiSpikes(), (this.getX()), (this.getY()));
       }
    }
}

